/*
 * Copyright (C) 2004-2014 L2J DataPack
 * 
 * This file is part of L2J DataPack.
 * 
 * L2J DataPack is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * L2J DataPack is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package custom.service;

import com.l2jserver.gameserver.model.actor.L2Npc;
import com.l2jserver.gameserver.model.actor.instance.L2PcInstance;
import com.l2jserver.gameserver.model.quest.Quest;
import com.l2jserver.gameserver.network.SystemMessageId;
import com.l2jserver.gameserver.network.serverpackets.SocialAction;
import com.l2jserver.gameserver.network.serverpackets.UserInfo;

/**
 * Повысит уровень персонажа до(LVL) указанный нпц(NPC_ID) при первом разговоре.
 * @author LifeGame32
 */
public class IncreaseLevel extends Quest
{
	private static final int NPC_ID = 31032;
	
	private static final byte LVL = 80;
	
	public IncreaseLevel()
	{
		super(-1, IncreaseLevel.class.getSimpleName(), "Increase Level");
		addFirstTalkId(NPC_ID);
	}
	
	@Override
	public String onFirstTalk(L2Npc npc, L2PcInstance player)
	{
		if (player.getLevel() < LVL)
		{
			player.getStat().setLevel(LVL);
			player.broadcastPacket(new SocialAction(player.getObjectId(), SocialAction.LEVEL_UP));
			player.sendPacket(SystemMessageId.YOU_INCREASED_YOUR_LEVEL);
			player.sendPacket(new UserInfo(player));
		}
		
		npc.showChatWindow(player, 0);
		return null;
	}
	
	public static void main(String[] args)
	{
		new IncreaseLevel();
	}
	
}
